@@ -22,9 +22,9 @@ class BaseNode:
     >>> d.parent = b
     >>> print_tree(root, attr_list=["age"])
     a [age=90]
-    |-- b [age=65]
-    |   `-- d [age=40]
-    `-- c [age=60]
+    ├── b [age=65]
+    │   └── d [age=40]
+    └── c [age=60]
 
     >>> from bigtree import Node
     >>> root = Node("a", age=90)
@@ -36,9 +36,9 @@ class BaseNode:
     >>> d << b
     >>> print_tree(root, attr_list=["age"])
     a [age=90]
-    |-- b [age=65]
-    |   `-- d [age=40]
-    `-- c [age=60]
+    ├── b [age=65]
+    │   └── d [age=40]
+    └── c [age=60]
 
     Directly passing `parent` argument.
 
@@ -56,24 +56,24 @@ class BaseNode:
     >>> b = Node("b", children=[d])
     >>> a = Node("a", children=[b, c])
 
-    **Node Creation**
+    **BaseNode Creation**
 
-    Node can be created by instantiating a `Node` class or by using a *dictionary*.
+    Node can be created by instantiating a `BaseNode` class or by using a *dictionary*.
     If node is created with dictionary, all keys of dictionary will be stored as class attributes.
 
     >>> from bigtree import Node
     >>> root = Node.from_dict({"name": "a", "age": 90})
 
-    **Node Attributes**
+    **BaseNode Attributes**
 
     These are node attributes that have getter and/or setter methods.
 
-    Get and set other `Node`
+    Get and set other `BaseNode`
 
     1. ``parent``: Get/set parent node
     2. ``children``: Get/set child nodes
 
-    Get other `Node`
+    Get other `BaseNode`
 
     1. ``ancestors``: Get ancestors of node excluding self, iterator
     2. ``descendants``: Get descendants of node excluding self, iterator
@@ -82,7 +82,7 @@ class BaseNode:
     5. ``left_sibling``: Get sibling left of self
     6. ``right_sibling``: Get sibling right of self
 
-    Get `Node` configuration
+    Get `BaseNode` configuration
 
     1. ``node_path``: Get tuple of nodes from root
     2. ``is_root``: Get indicator if self is root node
@@ -91,7 +91,7 @@ class BaseNode:
     5. ``depth``: Get depth of self
     6. ``max_depth``: Get maximum depth from root to leaf node
 
-    **Node Methods**
+    **BaseNode Methods**
 
     These are methods available to be performed on `BaseNode`.
 
@@ -99,18 +99,20 @@ class BaseNode:
 
     1. ``from_dict()``: Create BaseNode from dictionary
 
-    `Node` methods
+    `BaseNode` methods
 
     1. ``describe()``: Get node information sorted by attributes, returns list of tuples
     2. ``get_attr(attr_name: str)``: Get value of node attribute
     3. ``set_attrs(attrs: dict)``: Set node attribute name(s) and value(s)
-    4. ``copy()``: Deep copy BaseNode
+    4. ``go_to(node: BaseNode)``: Get a path from own node to another node from same tree
+    5. ``copy()``: Deep copy BaseNode
+    6. ``sort()``: Sort child nodes
 
     ----
 
     """
 
-    def __init__(self, parent=None, children=None, **kwargs):
+    def __init__(self, parent=None, children: List = None, **kwargs):
         self.__parent = None
         self.__children = []
         if children is None:
@@ -132,20 +134,24 @@ class BaseNode:
         """
         return self.__parent
 
-    @parent.setter
-    def parent(self, new_parent):
-        """Set parent node
+    @staticmethod
+    def __check_parent_type(new_parent):
+        """Check parent type
 
         Args:
             new_parent (Self): parent node
         """
-        # Check type
         if not (isinstance(new_parent, BaseNode) or new_parent is None):
             raise TypeError(
                 f"Expect input to be BaseNode type or NoneType, received input type {type(new_parent)}"
             )
 
-        # Check for loop
+    def __check_parent_loop(self, new_parent):
+        """Check parent type
+
+        Args:
+            new_parent (Self): parent node
+        """
         if new_parent is not None:
             if new_parent is self:
                 raise LoopError("Error setting parent: Node cannot be parent of itself")
@@ -158,31 +164,50 @@ class BaseNode:
                     "Error setting parent: Node cannot be ancestor of itself"
                 )
 
-        # Customizable check before assigning parent
+    @parent.setter
+    def parent(self, new_parent):
+        """Set parent node
+
+        Args:
+            new_parent (Self): parent node
+        """
+        self.__check_parent_type(new_parent)
+        self.__check_parent_loop(new_parent)
+
+        current_parent = self.parent
+        current_child_idx = None
+
+        # Assign new parent - rollback if error
         self.__pre_assign_parent(new_parent)
+        try:
+            # Remove self from old parent
+            if current_parent is not None:
+                if not any(
+                    child is self for child in current_parent.children
+                ):  # pragma: no cover
+                    raise CorruptedTreeError(
+                        "Error setting parent: Node does not exist as children of its parent"
+                    )
+                current_child_idx = current_parent.__children.index(self)
+                current_parent.__children.remove(self)
 
-        current_parent = self.__parent
+            # Assign self to new parent
+            self.__parent = new_parent
+            if new_parent is not None:
+                new_parent.__children.append(self)
 
-        # Remove child from current_parent
-        if current_parent is not None:
-            # Check for loop tree structure
-            if not any(
-                child is self for child in current_parent.children
-            ):  # pragma: no cover
-                raise CorruptedTreeError(
-                    "Error setting parent: Node does not exist as children of its parent"
-                )
+            self.__post_assign_parent(new_parent)
 
-            # Detach child from current parent
-            current_parent.__children.remove(self)
+        except Exception as exc_info:
+            # Remove self from new parent
+            if new_parent is not None:
+                new_parent.__children.remove(self)
 
-        # Add child to new_parent
-        self.__parent = new_parent
-        if new_parent is not None:
-            new_parent.__children.append(self)
-
-        # Customizable check after assigning parent
-        self.__post_assign_parent(new_parent)
+            # Reassign self to old parent
+            self.__parent = current_parent
+            if current_child_idx is not None:
+                current_parent.__children.insert(current_child_idx, self)
+            raise TreeError(exc_info)
 
     def __pre_assign_parent(self, new_parent):
         """Custom method to check before attaching parent
@@ -227,18 +252,23 @@ class BaseNode:
         """
         return tuple(self.__children)
 
-    @children.setter
-    def children(self, new_children: List):
-        """Set child nodes
+    def __check_children_type(self, new_children: List):
+        """Check child type
 
         Args:
             new_children (List[Self]): child node
         """
         if not isinstance(new_children, list):
-            print(new_children)
             raise TypeError(
                 f"Children input should be list type, received input type {type(new_children)}"
             )
+
+    def __check_children_loop(self, new_children: List):
+        """Check child loop
+
+        Args:
+            new_children (List[Self]): child node
+        """
         seen_children = []
         for new_child in new_children:
             # Check type
@@ -263,23 +293,60 @@ class BaseNode:
             else:
                 seen_children.append(id(new_child))
 
-        # Detach existing child node(s)
+    @children.setter
+    def children(self, new_children: List):
+        """Set child nodes
+
+        Args:
+            new_children (List[Self]): child node
+        """
+        self.__check_children_type(new_children)
+        self.__check_children_loop(new_children)
+
+        current_new_children = {
+            new_child: (new_child.parent.__children.index(new_child), new_child.parent)
+            for new_child in new_children
+            if new_child.parent is not None
+        }
+        current_new_orphan = [
+            new_child for new_child in new_children if new_child.parent is None
+        ]
         current_children = list(self.children)
-        del self.children
+
+        # Assign new children - rollback if error
+        self.__pre_assign_children(new_children)
         try:
-            self.__pre_assign_children(new_children)
+            # Remove old children from self
+            del self.children
+
+            # Assign new children to self
+            self.__children = new_children
             for new_child in new_children:
-                new_child.parent = self
+                if new_child.parent:
+                    new_child.parent.__children.remove(new_child)
+                new_child.__parent = self
             self.__post_assign_children(new_children)
-        except TreeError or TypeError as exc_info:
-            self.children = current_children
+        except Exception as exc_info:
+            # Reassign new children to their original parent
+            for child, idx_parent in current_new_children.items():
+                child_idx, parent = idx_parent
+                child.__parent = parent
+                parent.__children.insert(child_idx, child)
+            for child in current_new_orphan:
+                child.__parent = None
+
+            # Reassign old children to self
+            self.__children = current_children
+            for child in current_children:
+                child.__parent = self
             raise TreeError(exc_info)
 
     @children.deleter
     def children(self):
         """Delete child node(s)"""
         for child in self.children:
-            child.parent = None
+            child.parent.__children.remove(child)
+            child.__parent = None
 
     def __pre_assign_children(self, new_children: List):
         """Custom method to check before attaching children
@@ -447,6 +514,15 @@ class BaseNode:
     def describe(self, exclude_attributes: List[str] = [], exclude_prefix: str = ""):
         """Get node information sorted by attribute name, returns list of tuples
 
+        >>> from bigtree.node.node import Node
+        >>> a = Node('a', age=90)
+        >>> a.describe()
+        [('_BaseNode__children', []), ('_BaseNode__parent', None), ('_sep', '/'), ('age', 90), ('name', 'a')]
+        >>> a.describe(exclude_prefix="_")
+        [('age', 90), ('name', 'a')]
+        >>> a.describe(exclude_prefix="_", exclude_attributes=["name"])
+        [('age', 90)]
+
         Args:
             exclude_attributes (List[str]): list of attributes to exclude
             exclude_prefix (str): prefix of attributes to exclude
@@ -465,6 +541,11 @@ class BaseNode:
         """Get value of node attribute
         Returns None if attribute name does not exist
 
+        >>> from bigtree.node.node import Node
+        >>> a = Node('a', age=90)
+        >>> a.get_attr("age")
+        90
+
         Args:
             attr_name (str): attribute name
 
@@ -479,12 +560,71 @@ class BaseNode:
     def set_attrs(self, attrs: Dict[str, Any]):
         """Set node attributes
 
+        >>> from bigtree.node.node import Node
+        >>> a = Node('a')
+        >>> a.set_attrs({"age": 90})
+        >>> a
+        Node(/a, age=90)
+
         Args:
             attrs (Dict[str, Any]): attribute dictionary,
                 key: attribute name, value: attribute value
         """
         self.__dict__.update(attrs)
 
+    def go_to(self, node) -> Iterable:
+        """Get path from current node to specified node from same tree
+
+        >>> from bigtree import Node, print_tree
+        >>> a = Node(name="a")
+        >>> b = Node(name="b", parent=a)
+        >>> c = Node(name="c", parent=a)
+        >>> d = Node(name="d", parent=b)
+        >>> e = Node(name="e", parent=b)
+        >>> f = Node(name="f", parent=c)
+        >>> g = Node(name="g", parent=e)
+        >>> h = Node(name="h", parent=e)
+        >>> print_tree(a)
+        a
+        ├── b
+        │   ├── d
+        │   └── e
+        │       ├── g
+        │       └── h
+        └── c
+            └── f
+        >>> d.go_to(d)
+        [Node(/a/b/d, )]
+        >>> d.go_to(g)
+        [Node(/a/b/d, ), Node(/a/b, ), Node(/a/b/e, ), Node(/a/b/e/g, )]
+        >>> d.go_to(f)
+        [Node(/a/b/d, ), Node(/a/b, ), Node(/a, ), Node(/a/c, ), Node(/a/c/f, )]
+
+        Args:
+            node (Self): node to travel to from current node, inclusive of start and end node
+
+        Returns:
+            (Iterable)
+        """
+        if not isinstance(node, BaseNode):
+            raise TypeError(
+                f"Expect node to be BaseNode type, received input type {type(node)}"
+            )
+        if self.root != node.root:
+            raise TreeError(
+                f"Nodes are not from the same tree. Check {self} and {node}"
+            )
+        if self == node:
+            return [self]
+        self_path = [self] + list(self.ancestors)
+        node_path = ([node] + list(node.ancestors))[::-1]
+        common_nodes = set(self_path).intersection(set(node_path))
+        self_min_index, min_common_node = sorted(
+            [(self_path.index(_node), _node) for _node in common_nodes]
+        )[0]
+        node_min_index = node_path.index(min_common_node)
+        return self_path[:self_min_index] + node_path[node_min_index:]
+
     def copy(self):
         """Deep copy self; clone BaseNode
 
@@ -497,6 +637,27 @@ class BaseNode:
         """
         return copy.deepcopy(self)
 
+    def sort(self, **kwargs):
+        """Sort children, possible keyword arguments include ``key=lambda node: node.name``, ``reverse=True``
+
+        >>> from bigtree import Node, print_tree
+        >>> a = Node('a')
+        >>> c = Node("c", parent=a)
+        >>> b = Node("b", parent=a)
+        >>> print_tree(a)
+        a
+        ├── c
+        └── b
+        >>> a.sort(key=lambda node: node.name)
+        >>> print_tree(a)
+        a
+        ├── b
+        └── c
+        """
+        children = list(self.children)
+        children.sort(**kwargs)
+        self.__children = children
+
     def __copy__(self):
         """Shallow copy self
 
