@@ -1,3 +1,4 @@
+import re
 from collections import OrderedDict
 from typing import List, Tuple, Type
 
@@ -15,8 +16,9 @@ __all__ = [
     "add_dict_to_tree_by_name",
     "add_dataframe_to_tree_by_path",
     "add_dataframe_to_tree_by_name",
-    "list_to_tree_by_relation",
+    "str_to_tree",
     "list_to_tree",
+    "list_to_tree_by_relation",
     "dict_to_tree",
     "nested_dict_to_tree",
     "dataframe_to_tree",
@@ -143,7 +145,7 @@ def add_dict_to_tree_by_path(
 
     Args:
         tree (Node): existing tree
-        path_attrs (dict): dictioning containing node path and attribute information,
+        path_attrs (dict): dictionary containing node path and attribute information,
             key: node path, value: dict of node attribute name and attribute value
         sep (str): path separator for input `path_attrs`
         duplicate_name_allowed (bool): indicator if nodes with duplicated `Node` name is allowed, defaults to True
@@ -170,7 +172,7 @@ def add_dict_to_tree_by_path(
 def add_dict_to_tree_by_name(
     tree: Node, path_attrs: dict, join_type: str = "left"
 ) -> Node:
-    """Add nodes and attributes to tree, return *new* root of tree.
+    """Add attributes to tree, return *new* root of tree.
     Adds to existing tree from nested dictionary, ``key``: name, ``value``: dict of attribute name and attribute value.
 
     Function can return all existing tree nodes or only tree nodes that are in the input dictionary keys.
@@ -191,7 +193,7 @@ def add_dict_to_tree_by_name(
 
     Args:
         tree (Node): existing tree
-        path_attrs (dict): dictioning containing node name and attribute information,
+        path_attrs (dict): dictionary containing node name and attribute information,
             key: node name, value: dict of node attribute name and attribute value
         join_type (str): join type with attribute, default of 'left' takes existing tree nodes,
             if join_type is set to 'inner' it will only take tree nodes that are in `path_attrs` key and drop others
@@ -219,6 +221,7 @@ def add_dataframe_to_tree_by_path(
     duplicate_name_allowed: bool = True,
 ) -> Node:
     """Add nodes and attributes to tree *in-place*, return root of tree.
+
     `path_col` and `attribute_cols` specify columns for node path and attributes to add to existing tree.
     If columns are not specified, `path_col` takes first column and all other columns are `attribute_cols`
 
@@ -319,7 +322,7 @@ def add_dataframe_to_tree_by_name(
     attribute_cols: list = [],
     join_type: str = "left",
 ):
-    """Add nodes and attributes to tree, return *new* root of tree.
+    """Add attributes to tree, return *new* root of tree.
 
     `name_col` and `attribute_cols` specify columns for node name and attributes to add to existing tree.
     If columns are not specified, the first column will be taken as name column and all other columns as attributes.
@@ -405,17 +408,16 @@ def add_dataframe_to_tree_by_name(
     )
 
 
-def list_to_tree_by_relation(
-    relations: List[Tuple[str, str]],
+def str_to_tree(
+    tree_string: str,
+    tree_prefix_list: List[str] = [],
     node_type: Type[Node] = Node,
 ) -> Node:
-    """Construct tree from list of tuple containing parent-child names.
-    Note that node names must be unique since tree is created from parent-child names,
-    except for leaf nodes - names of leaf nodes may be repeated as there is no confusion.
+    r"""Construct tree from tree string
 
-    >>> from bigtree import list_to_tree_by_relation, print_tree
-    >>> relations_list = [("a", "b"), ("a", "c"), ("b", "d"), ("b", "e"), ("c", "f"), ("e", "g"), ("e", "h")]
-    >>> root = list_to_tree_by_relation(relations_list)
+    >>> from bigtree import str_to_tree, print_tree
+    >>> tree_str = 'a\n├── b\n│   ├── d\n│   └── e\n│       ├── g\n│       └── h\n└── c\n    └── f'
+    >>> root = str_to_tree(tree_str, tree_prefix_list=["├──", "└──"])
     >>> print_tree(root)
     a
     ├── b
@@ -427,19 +429,51 @@ def list_to_tree_by_relation(
         └── f
 
     Args:
-        relations (list): list containing tuple containing parent-child names
+        tree_string (str): String to construct tree
+        tree_prefix_list (list): List of prefix to mark the end of tree branch/stem and start of node name, optional.
+            If not specified, it will infer unicode characters and whitespace as prefix.
         node_type (Type[Node]): node type of tree to be created, defaults to Node
 
     Returns:
         (Node)
     """
-    if not len(relations):
-        raise ValueError("Path list does not contain any data, check `relations`")
+    tree_string = tree_string.strip("\n")
+    if not len(tree_string):
+        raise ValueError("Tree string does not contain any data, check `tree_string`")
+    tree_list = tree_string.split("\n")
+    tree_root = node_type(tree_list[0])
 
-    relation_data = pd.DataFrame(relations, columns=["parent", "child"])
-    return dataframe_to_tree_by_relation(
-        relation_data, child_col="child", parent_col="parent", node_type=node_type
-    )
+    # Infer prefix length
+    prefix_length = None
+    cur_parent = tree_root
+    for node_str in tree_list[1:]:
+        if len(tree_prefix_list):
+            node_name = re.split("|".join(tree_prefix_list), node_str)[-1].lstrip()
+        else:
+            node_name = node_str.encode("ascii", "ignore").decode("ascii").lstrip()
+
+        # Find node parent
+        if not prefix_length:
+            prefix_length = node_str.index(node_name)
+            if not prefix_length:
+                raise ValueError(
+                    f"Invalid prefix, prefix should be unicode character or whitespace, "
+                    f"otherwise specify one or more prefixes in `tree_prefix_list`, check: {node_str}"
+                )
+        node_prefix_length = node_str.index(node_name)
+        if node_prefix_length % prefix_length:
+            raise ValueError(
+                f"Tree string have different prefix length, check branch: {node_str}"
+            )
+        while cur_parent.depth > node_prefix_length / prefix_length:
+            cur_parent = cur_parent.parent
+
+        # Link node
+        child_node = node_type(node_name)
+        child_node.parent = cur_parent
+        cur_parent = child_node
+
+    return tree_root
 
 
 def list_to_tree(
@@ -500,6 +534,44 @@ def list_to_tree(
     return root_node
 
 
+def list_to_tree_by_relation(
+    relations: List[Tuple[str, str]],
+    node_type: Type[Node] = Node,
+) -> Node:
+    """Construct tree from list of tuple containing parent-child names.
+
+    Note that node names must be unique since tree is created from parent-child names,
+    except for leaf nodes - names of leaf nodes may be repeated as there is no confusion.
+
+    >>> from bigtree import list_to_tree_by_relation, print_tree
+    >>> relations_list = [("a", "b"), ("a", "c"), ("b", "d"), ("b", "e"), ("c", "f"), ("e", "g"), ("e", "h")]
+    >>> root = list_to_tree_by_relation(relations_list)
+    >>> print_tree(root)
+    a
+    ├── b
+    │   ├── d
+    │   └── e
+    │       ├── g
+    │       └── h
+    └── c
+        └── f
+
+    Args:
+        relations (list): list containing tuple containing parent-child names
+        node_type (Type[Node]): node type of tree to be created, defaults to Node
+
+    Returns:
+        (Node)
+    """
+    if not len(relations):
+        raise ValueError("Path list does not contain any data, check `relations`")
+
+    relation_data = pd.DataFrame(relations, columns=["parent", "child"])
+    return dataframe_to_tree_by_relation(
+        relation_data, child_col="child", parent_col="parent", node_type=node_type
+    )
+
+
 def dict_to_tree(
     path_attrs: dict,
     sep: str = "/",
@@ -541,7 +613,7 @@ def dict_to_tree(
         └── f [age=38]
 
     Args:
-        path_attrs (dict): dictioning containing path and node attribute information,
+        path_attrs (dict): dictionary containing path and node attribute information,
             key: path, value: dict of tree attribute and attribute value
         sep (str): path separator of input `path_attrs` and created tree, defaults to `/`
         duplicate_name_allowed (bool): indicator if nodes with duplicated `Node` name is allowed, defaults to True
@@ -570,7 +642,7 @@ def nested_dict_to_tree(
     node_type: Type[Node] = Node,
 ) -> Node:
     """Construct tree from nested recursive dictionary.
-      - ``key``: `name_key`, `child_key`, or any attributes.
+      - ``key``: `name_key`, `child_key`, or any attributes key.
       - ``value`` of `name_key` (str): node name.
       - ``value`` of `child_key` (list): list of dict containing `name_key` and `child_key` (recursive).
 
@@ -598,7 +670,7 @@ def nested_dict_to_tree(
             └── g [age=10]
 
     Args:
-        node_attrs (dict): dictioning containing node, children, and node attribute information,
+        node_attrs (dict): dictionary containing node, children, and node attribute information,
             key: `name_key` and `child_key`
             value of `name_key` (str): node name
             value of `child_key` (list): list of dict containing `name_key` and `child_key` (recursive)
@@ -632,6 +704,7 @@ def dataframe_to_tree(
     node_type: Type[Node] = Node,
 ) -> Node:
     """Construct tree from pandas DataFrame using path, return root of tree.
+
     `path_col` and `attribute_cols` specify columns for node path and attributes to construct tree.
     If columns are not specified, `path_col` takes first column and all other columns are `attribute_cols`.
 
@@ -728,6 +801,7 @@ def dataframe_to_tree_by_relation(
     node_type: Type[Node] = Node,
 ) -> Node:
     """Construct tree from pandas DataFrame using parent and child names, return root of tree.
+
     Note that node names must be unique since tree is created from parent-child names,
     except for leaf nodes - names of leaf nodes may be repeated as there is no confusion.
 
@@ -834,7 +908,7 @@ def dataframe_to_tree_by_relation(
 
     # Create root node attributes
     if len(root_row):
-        node_attrs = retrieve_attr(list(root_row.to_dict(orient="index").values())[0])
-        root_node.set_attrs(node_attrs)
+        row = list(root_row.to_dict(orient="index").values())[0]
+        root_node.set_attrs(retrieve_attr(row))
     recursive_create_child(root_node)
     return root_node
