@@ -1,5 +1,5 @@
 import collections
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Tuple, Union
 
 import pandas as pd
 
@@ -14,6 +14,7 @@ __all__ = [
     "tree_to_nested_dict",
     "tree_to_dataframe",
     "tree_to_dot",
+    "tree_to_pillow",
 ]
 
 
@@ -307,7 +308,8 @@ def yield_tree(
     tree = tree.copy()
     if node_name_or_path:
         tree = find_path(tree, node_name_or_path)
-    tree.parent = None
+    if not tree.is_root:
+        tree.parent = None
 
     # Set style
     if style == "custom":
@@ -401,29 +403,34 @@ def tree_to_dict(
     data_dict = {}
 
     def recursive_append(node):
-        if (
-            (not max_depth or node.depth <= max_depth)
-            and (not skip_depth or node.depth > skip_depth)
-            and (not leaf_only or node.is_leaf)
-        ):
-            data_child = {}
-            if name_key:
-                data_child[name_key] = node.node_name
-            if parent_key:
-                parent_name = None
-                if node.parent:
-                    parent_name = node.parent.node_name
-                data_child[parent_key] = parent_name
-            if all_attrs:
-                data_child.update(
-                    dict(node.describe(exclude_attributes=["name"], exclude_prefix="_"))
-                )
-            else:
-                for k, v in attr_dict.items():
-                    data_child[v] = node.get_attr(k)
-            data_dict[node.path_name] = data_child
-        for _node in node.children:
-            recursive_append(_node)
+        if node:
+            if (
+                (not max_depth or node.depth <= max_depth)
+                and (not skip_depth or node.depth > skip_depth)
+                and (not leaf_only or node.is_leaf)
+            ):
+                data_child = {}
+                if name_key:
+                    data_child[name_key] = node.node_name
+                if parent_key:
+                    parent_name = None
+                    if node.parent:
+                        parent_name = node.parent.node_name
+                    data_child[parent_key] = parent_name
+                if all_attrs:
+                    data_child.update(
+                        dict(
+                            node.describe(
+                                exclude_attributes=["name"], exclude_prefix="_"
+                            )
+                        )
+                    )
+                else:
+                    for k, v in attr_dict.items():
+                        data_child[v] = node.get_attr(k)
+                data_dict[node.path_name] = data_child
+            for _node in node.children:
+                recursive_append(_node)
 
     recursive_append(tree)
     return data_dict
@@ -468,22 +475,27 @@ def tree_to_nested_dict(
     data_dict = {}
 
     def recursive_append(node, parent_dict):
-        if not max_depth or node.depth <= max_depth:
-            data_child = {name_key: node.node_name}
-            if all_attrs:
-                data_child.update(
-                    dict(node.describe(exclude_attributes=["name"], exclude_prefix="_"))
-                )
-            else:
-                for k, v in attr_dict.items():
-                    data_child[v] = node.get_attr(k)
-            if child_key in parent_dict:
-                parent_dict[child_key].append(data_child)
-            else:
-                parent_dict[child_key] = [data_child]
+        if node:
+            if not max_depth or node.depth <= max_depth:
+                data_child = {name_key: node.node_name}
+                if all_attrs:
+                    data_child.update(
+                        dict(
+                            node.describe(
+                                exclude_attributes=["name"], exclude_prefix="_"
+                            )
+                        )
+                    )
+                else:
+                    for k, v in attr_dict.items():
+                        data_child[v] = node.get_attr(k)
+                if child_key in parent_dict:
+                    parent_dict[child_key].append(data_child)
+                else:
+                    parent_dict[child_key] = [data_child]
 
-            for _node in node.children:
-                recursive_append(_node, data_child)
+                for _node in node.children:
+                    recursive_append(_node, data_child)
 
     recursive_append(tree, data_dict)
     return data_dict[child_key][0]
@@ -546,32 +558,33 @@ def tree_to_dataframe(
     data_list = []
 
     def recursive_append(node):
-        if (
-            (not max_depth or node.depth <= max_depth)
-            and (not skip_depth or node.depth > skip_depth)
-            and (not leaf_only or node.is_leaf)
-        ):
-            data_child = {}
-            if path_col:
-                data_child[path_col] = node.path_name
-            if name_col:
-                data_child[name_col] = node.node_name
-            if parent_col:
-                parent_name = None
-                if node.parent:
-                    parent_name = node.parent.node_name
-                data_child[parent_col] = parent_name
+        if node:
+            if (
+                (not max_depth or node.depth <= max_depth)
+                and (not skip_depth or node.depth > skip_depth)
+                and (not leaf_only or node.is_leaf)
+            ):
+                data_child = {}
+                if path_col:
+                    data_child[path_col] = node.path_name
+                if name_col:
+                    data_child[name_col] = node.node_name
+                if parent_col:
+                    parent_name = None
+                    if node.parent:
+                        parent_name = node.parent.node_name
+                    data_child[parent_col] = parent_name
 
-            if all_attrs:
-                data_child.update(
-                    node.describe(exclude_attributes=["name"], exclude_prefix="_")
-                )
-            else:
-                for k, v in attr_dict.items():
-                    data_child[v] = node.get_attr(k)
-            data_list.append(data_child)
-        for _node in node.children:
-            recursive_append(_node)
+                if all_attrs:
+                    data_child.update(
+                        node.describe(exclude_attributes=["name"], exclude_prefix="_")
+                    )
+                else:
+                    for k, v in attr_dict.items():
+                        data_child[v] = node.get_attr(k)
+                data_list.append(data_child)
+            for _node in node.children:
+                recursive_append(_node)
 
     recursive_append(tree)
     return pd.DataFrame(data_list)
@@ -585,6 +598,7 @@ def tree_to_dot(
     node_colour: str = None,
     edge_colour: str = None,
     node_attr: str = None,
+    edge_attr: str = None,
 ):
     r"""Export tree or list of trees to image.
     Posible node attributes include style, fillcolor, shape.
@@ -607,14 +621,45 @@ def tree_to_dot(
     >>> graph.to_string()
     'strict digraph G {\nrankdir=TB;\na0 [label=a];\nb0 [label=b];\na0 -> b0;\nd0 [label=d];\nb0 -> d0;\ne0 [label=e];\nb0 -> e0;\nc0 [label=c];\na0 -> c0;\n}\n'
 
+    Defining node and edge attributes
+
+    >>> class CustomNode(Node):
+    ...     def __init__(self, name, node_shape="", edge_label="", **kwargs):
+    ...         super().__init__(name, **kwargs)
+    ...         self.node_shape = node_shape
+    ...         self.edge_label = edge_label
+    ...
+    ...     @property
+    ...     def edge_attr(self):
+    ...         return {"label": self.edge_label}
+    ...
+    ...     @property
+    ...     def node_attr(self):
+    ...         return {"shape": self.node_shape}
+    >>>
+    >>>
+    >>> root = CustomNode("a", node_shape="circle")
+    >>> b = CustomNode("b", node_shape="diamond", edge_label="child", parent=root)
+    >>> c = CustomNode("c", node_shape="diamond", edge_label="child", parent=root)
+    >>> d = CustomNode("d", node_shape="square", edge_label="child", parent=b)
+    >>> e = CustomNode("e", node_shape="square", edge_label="child", parent=b)
+    >>> graph = tree_to_dot(root, node_colour="gold", node_attr="node_attr", edge_attr="edge_attr")
+    >>> graph.write_png("assets/custom_tree.png")
+
+    .. image:: https://github.com/kayjan/bigtree/raw/master/assets/custom_tree.png
+
     Args:
         tree (Node/List[Node]): tree or list of trees to be exported
         directed (bool): indicator whether graph should be directed or undirected, defaults to True
-        rankdir (str): set direction of graph layout, defaults to 'TB', can be 'BT, 'LR', 'RL'
+        rankdir (str): set direction of graph layout, defaults to 'TB' (top to bottom), can be 'BT' (bottom to top),
+            'LR' (left to right), 'RL' (right to left)
         bg_colour (str): background color of image, defaults to None
         node_colour (str): fill colour of nodes, defaults to None
         edge_colour (str): colour of edges, defaults to None
-        node_attr (str): node attribute for style, overrides node_colour, defaults to None
+        node_attr (str): `Node` attribute for node style, overrides node_colour, defaults to None.
+            Possible node style (attribute value) include {"style": "filled", "fillcolor": "gold", "shape": "diamond"}
+        edge_attr (str): `Node` attribute for edge style, overrides edge_colour, defaults to None.
+            Possible edge style (attribute value) include {"style": "bold", "label": "edge label", "color": "black"}
 
     Returns:
         (pydot.Dot)
@@ -663,6 +708,9 @@ def tree_to_dot(
         name_dict = collections.defaultdict(list)
 
         def recursive_create_node_and_edges(parent_name, child_node):
+            _node_style = node_style.copy()
+            _edge_style = edge_style.copy()
+
             child_label = child_node.node_name
             if child_node.path_name not in name_dict[child_label]:  # pragma: no cover
                 name_dict[child_label].append(child_node.path_name)
@@ -670,14 +718,104 @@ def tree_to_dot(
                 name_dict[child_label].index(child_node.path_name)
             )
             if node_attr and child_node.get_attr(node_attr):
-                node_style.update(child_node.get_attr(node_attr))
-            node = pydot.Node(name=child_name, label=child_label, **node_style)
+                _node_style.update(child_node.get_attr(node_attr))
+            if edge_attr:
+                _edge_style.update(child_node.get_attr(edge_attr))
+            node = pydot.Node(name=child_name, label=child_label, **_node_style)
             _graph.add_node(node)
             if parent_name is not None:
-                edge = pydot.Edge(parent_name, child_name, **edge_style)
+                edge = pydot.Edge(parent_name, child_name, **_edge_style)
                 _graph.add_edge(edge)
             for child in child_node.children:
-                recursive_create_node_and_edges(child_name, child)
+                if child:
+                    recursive_create_node_and_edges(child_name, child)
 
         recursive_create_node_and_edges(None, _tree.root)
     return _graph
+
+
+def tree_to_pillow(
+    tree: Node,
+    width: int = 0,
+    height: int = 0,
+    start_pos: Tuple[float, float] = (10, 10),
+    font_family: str = "assets/DejaVuSans.ttf",
+    font_size: int = 12,
+    font_colour: Union[Tuple[float, float, float], str] = "black",
+    bg_colour: Union[Tuple[float, float, float], str] = "white",
+    **kwargs,
+):
+    """Export tree to image (JPG, PNG).
+    Image will be similar format as `print_tree`, accepts additional keyword arguments as input to `yield_tree`
+
+    >>> from bigtree import Node, tree_to_pillow
+    >>> root = Node("a", age=90)
+    >>> b = Node("b", age=65, parent=root)
+    >>> c = Node("c", age=60, parent=root)
+    >>> d = Node("d", age=40, parent=b)
+    >>> e = Node("e", age=35, parent=b)
+    >>> pillow_image = tree_to_pillow(root)
+
+    Export to image (PNG, JPG) file, etc.
+
+    >>> pillow_image.save("tree_pillow.png")
+    >>> pillow_image.save("tree_pillow.jpg")
+
+    Args:
+        tree (Node): tree to be exported
+        width (int): width of image, optional as width of image is calculated automatically
+        height (int): height of image, optional as height of image is calculated automatically
+        start_pos (Tuple[float, float]): start position of text, (x-offset, y-offset), defaults to (10, 10)
+        font_family (str): file path of font family, requires .ttf file, defaults to DejaVuSans
+        font_size (int): font size, defaults to 12
+        font_colour (Union[List[int], str]): font colour, accepts tuple of RGB values or string, defaults to black
+        bg_colour (Union[List[int], str]): background of image, accepts tuple of RGB values or string, defaults to white
+
+    Returns:
+        (PIL.Image.Image)
+    """
+    try:
+        from PIL import Image, ImageDraw, ImageFont
+    except ImportError:  # pragma: no cover
+        raise ImportError(
+            "Pillow not available. Please perform a\n\npip install 'bigtree[image]'\n\nto install required dependencies"
+        )
+
+    # Initialize font
+    font = ImageFont.truetype(font_family, font_size)
+
+    # Initialize text
+    image_text = []
+    for branch, stem, node in yield_tree(tree, **kwargs):
+        image_text.append(f"{branch}{stem}{node.node_name}\n")
+
+    # Calculate image dimension from text, otherwise override with argument
+    def get_list_of_text_dimensions(text_list):
+        """Get list dimensions
+
+        Args:
+            text_list (List[str]): list of texts
+
+        Returns:
+            (List[Iterable[int]]): list of (left, top, right, bottom) bounding box
+        """
+        _image = Image.new("RGB", (0, 0))
+        _draw = ImageDraw.Draw(_image)
+        return [_draw.textbbox((0, 0), text_line, font=font) for text_line in text_list]
+
+    text_dimensions = get_list_of_text_dimensions(image_text)
+    text_height = sum(
+        [text_dimension[3] + text_dimension[1] for text_dimension in text_dimensions]
+    )
+    text_width = max(
+        [text_dimension[2] + text_dimension[0] for text_dimension in text_dimensions]
+    )
+    image_text = "".join(image_text)
+    width = max(width, text_width + 2 * start_pos[0])
+    height = max(height, text_height + 2 * start_pos[1])
+
+    # Initialize and draw image
+    image = Image.new("RGB", (width, height), bg_colour)
+    image_draw = ImageDraw.Draw(image)
+    image_draw.text(start_pos, image_text, font=font, fill=font_colour)
+    return image
