@@ -3,6 +3,7 @@ from typing import Optional, Type
 import numpy as np
 
 from bigtree.node.basenode import BaseNode
+from bigtree.node.binarynode import BinaryNode
 from bigtree.node.node import Node
 from bigtree.tree.construct import dataframe_to_tree
 from bigtree.tree.export import tree_to_dataframe
@@ -40,10 +41,11 @@ def clone_tree(tree: BaseNode, node_type: Type[BaseNode]) -> BaseNode:
 
     def recursive_add_child(_new_parent_node, _parent_node):
         for _child in _parent_node.children:
-            child_info = dict(_child.describe(exclude_prefix="_"))
-            child_node = node_type(**child_info)
-            child_node.parent = _new_parent_node
-            recursive_add_child(child_node, _child)
+            if _child:
+                child_info = dict(_child.describe(exclude_prefix="_"))
+                child_node = node_type(**child_info)
+                child_node.parent = _new_parent_node
+                recursive_add_child(child_node, _child)
 
     recursive_add_child(root_node, tree.root)
     return root_node
@@ -88,6 +90,12 @@ def prune_tree(tree: Node, prune_path: str, sep: str = "/") -> Node:
             f"Cannot find any node matching path_name ending with {prune_path}"
         )
 
+    if isinstance(child.parent, BinaryNode):
+        while child.parent:
+            child.parent.children = [child, None]
+            child = child.parent
+        return tree_copy
+
     while child.parent:
         child.parent.children = [child]
         child = child.parent
@@ -103,32 +111,58 @@ def get_tree_diff(
       - For example: (+) refers to nodes that are in `other_tree` but not `tree`.
       - For example: (-) refers to nodes that are in `tree` but not `other_tree`.
 
+    Note that only leaf nodes are compared and have (+) or (-) indicator. Intermediate parent nodes are not compared.
+
     Function can return all original tree nodes and differences, or only the differences.
 
     >>> from bigtree import Node, get_tree_diff, print_tree
     >>> root = Node("a")
     >>> b = Node("b", parent=root)
     >>> c = Node("c", parent=root)
+    >>> d = Node("d", parent=b)
+    >>> e = Node("e", parent=root)
     >>> print_tree(root)
     a
     ├── b
-    └── c
+    │   └── d
+    ├── c
+    └── e
 
     >>> root_other = Node("a")
     >>> b_other = Node("b", parent=root_other)
+    >>> c_other = Node("c", parent=b_other)
+    >>> d_other = Node("d", parent=root_other)
+    >>> e_other = Node("e", parent=root_other)
     >>> print_tree(root_other)
     a
-    └── b
+    ├── b
+    │   └── c
+    ├── d
+    └── e
 
     >>> tree_diff = get_tree_diff(root, root_other)
     >>> print_tree(tree_diff)
     a
-    └── c (-)
+    ├── b
+    │   ├── c (+)
+    │   └── d (-)
+    ├── c (-)
+    └── d (+)
+
+    >>> tree_diff = get_tree_diff(root, root_other, only_diff=False)
+    >>> print_tree(tree_diff)
+    a
+    ├── b
+    │   ├── c (+)
+    │   └── d (-)
+    ├── c (-)
+    ├── d (+)
+    └── e
 
     Args:
         tree (Node): tree to be compared against
         other_tree (Node): tree to be compared with
-        only_diff (bool): indicator to show only nodes that are different (added and subtracted), defaults to True
+        only_diff (bool): indicator to show all nodes or only nodes that are different (+/-), defaults to True
 
     Returns:
         (Node)
