@@ -16,6 +16,7 @@ from bigtree.tree.construct import (
     list_to_tree,
     list_to_tree_by_relation,
     nested_dict_to_tree,
+    str_to_tree,
 )
 from bigtree.tree.export import print_tree
 from bigtree.tree.search import find_name, find_names
@@ -292,7 +293,7 @@ class TestAddDictToTreeByPath(unittest.TestCase):
 
         add_dict_to_tree_by_path(self.root, paths)
         assert_tree_structure_basenode_root_generic(self.root)
-        assert_tree_structure_basenode_root_attr(self.root)
+        assert_tree_structure_basenode_root_attr(self.root, f=("d", 38))
 
     def test_add_dict_to_tree_by_path_node_type(self):
         root = NodeA("a", age=1)
@@ -413,7 +414,7 @@ class TestAddDictToTreeByName(unittest.TestCase):
         assert_tree_structure_node_root_generic(root)
 
     def test_add_dict_to_tree_by_name_left_join(self):
-        root = add_dict_to_tree_by_name(self.root, {"a": {"age": 90}}, join_type="left")
+        root = add_dict_to_tree_by_name(self.root, self.name_dict, join_type="left")
         assert_tree_structure_basenode_root_generic(root)
         assert_tree_structure_basenode_root_attr(root)
         assert_tree_structure_node_root_generic(root)
@@ -432,14 +433,15 @@ class TestAddDictToTreeByName(unittest.TestCase):
         b = NodeA("b", parent=root, age=1)
         c = NodeA("c", parent=root, age=1)
         d = NodeA("d", age=1)
-        e = NodeA("e", parent=b)
+        e = NodeA("e")
         f = NodeA("f")
         g = NodeA("g")
         h = NodeA("h")
         d.parent = b
+        e.parent = b
         f.parent = c
         g.parent = e
-        h.parent = b
+        h.parent = e
         root = add_dict_to_tree_by_name(root, self.name_dict)
         assert isinstance(root, NodeA), "Node type is not `NodeA`"
         assert_tree_structure_basenode_root_generic(root)
@@ -661,8 +663,8 @@ class TestAddDataFrameToTreeByPath(unittest.TestCase):
 
         add_dataframe_to_tree_by_path(self.root, data)
         assert_tree_structure_basenode_root_generic(self.root)
-        assert_tree_structure_basenode_root_attr(self.root)
-        assert_tree_structure_node_root_generic(self.root)
+        assert_tree_structure_basenode_root_attr(self.root, f=("d", 38))
+        assert_tree_structure_node_root_generic(self.root, f="/a/c/d")
 
 
 class TestAddDataFrameToTreeByName(unittest.TestCase):
@@ -773,13 +775,7 @@ class TestAddDataFrameToTreeByName(unittest.TestCase):
         assert_tree_structure_node_root_generic(root)
 
     def test_add_dataframe_to_tree_by_name_left_join(self):
-        data = pd.DataFrame(
-            [
-                ["a", 90],
-            ],
-            columns=["NAME", "age"],
-        )
-        root = add_dataframe_to_tree_by_name(self.root, data, join_type="left")
+        root = add_dataframe_to_tree_by_name(self.root, self.data, join_type="left")
         assert_tree_structure_basenode_root_generic(root)
         assert_tree_structure_basenode_root_attr(root)
         assert_tree_structure_node_root_generic(root)
@@ -798,14 +794,15 @@ class TestAddDataFrameToTreeByName(unittest.TestCase):
         b = NodeA("b", parent=root, age=1)
         c = NodeA("c", parent=root, age=1)
         d = NodeA("d", age=1)
-        e = NodeA("e", parent=b)
+        e = NodeA("e")
         f = NodeA("f")
         g = NodeA("g")
         h = NodeA("h")
         d.parent = b
+        e.parent = b
         f.parent = c
         g.parent = e
-        h.parent = b
+        h.parent = e
         root = add_dataframe_to_tree_by_name(root, self.data)
         assert isinstance(root, NodeA), "Node type is not `NodeA`"
         assert_tree_structure_basenode_root_generic(root)
@@ -834,20 +831,21 @@ class TestAddDataFrameToTreeByName(unittest.TestCase):
         b = Node("b", parent=root, age=1)
         c = Node("c", parent=root, age=1)
         d = Node("d", age=1)
-        e = Node("e", parent=b)
+        e = Node("e")
         f = Node("f")
         g = Node("g")
-        h = Node("g")  # duplicate node
+        h = Node("f")  # duplicate node
         d.parent = b
+        e.parent = b
         f.parent = c
         g.parent = e
-        h.parent = b
+        h.parent = e
         root = add_dataframe_to_tree_by_name(root, self.data)
         assert_tree_structure_basenode_root_generic(root)
-        assert_tree_structure_basenode_root_attr(root)
+        assert_tree_structure_basenode_root_attr(root, h=("f", 38))
 
 
-class TestListToTreeByRelation(unittest.TestCase):
+class TestStrToTree(unittest.TestCase):
     def setUp(self):
         """
         Tree should have structure
@@ -860,75 +858,60 @@ class TestListToTreeByRelation(unittest.TestCase):
         +-- c
             +-- f
         """
-        self.relations = [
-            ("a", "b"),
-            ("a", "c"),
-            ("b", "d"),
-            ("b", "e"),
-            ("c", "f"),
-            ("e", "g"),
-            ("e", "h"),
-        ]
+        self.tree_str = "a\n├── b\n│   ├── d\n│   └── e\n│       ├── g\n│       └── h\n└── c\n    └── f"
 
-    def tearDown(self):
-        self.relations = None
-
-    def test_list_to_tree_by_relation(self):
-        root = list_to_tree_by_relation(self.relations)
+    def test_str_to_tree(self):
+        root = str_to_tree(self.tree_str)
         assert_tree_structure_basenode_root_generic(root)
         assert_tree_structure_node_root_generic(root)
 
-    def test_list_to_tree_by_relation_reversed(self):
-        root = list_to_tree_by_relation(self.relations[::-1])
+    def test_str_to_tree_with_prefix(self):
+        root = str_to_tree(self.tree_str, tree_prefix_list=["─"])
         assert_tree_structure_basenode_root_generic(root)
         assert_tree_structure_node_root_generic(root)
 
-    @staticmethod
-    def test_list_to_tree_by_relation_duplicate_leaf_node():
-        relations = [
-            ("a", "b"),
-            ("a", "c"),
-            ("b", "d"),
-            ("b", "e"),
-            ("b", "h"),
-            ("c", "h"),
-            ("e", "g"),
-            ("e", "h"),
-        ]
-        root = list_to_tree_by_relation(relations)
-        expected = """a\n├── b\n│   ├── d\n│   ├── e\n│   │   ├── g\n│   │   └── h\n│   └── h\n└── c\n    └── h\n"""
-        assert_print_statement(print_tree, expected, tree=root, style="const")
-
-    def test_list_to_tree_by_relation_empty_parent(self):
-        self.relations = self.relations[::-1]
-        self.relations.append((None, "a"))
-        root = list_to_tree_by_relation(self.relations)
+    def test_str_to_tree_with_multiple_prefix(self):
+        root = str_to_tree(self.tree_str, tree_prefix_list=["├──", "└──"])
         assert_tree_structure_basenode_root_generic(root)
         assert_tree_structure_node_root_generic(root)
 
-    @staticmethod
-    def test_list_to_tree_by_relation_one_tuple():
-        root = list_to_tree_by_relation([(None, "a")])
-        assert root.max_depth == 1, "Max depth is wrong"
-        assert root.node_name == "a", "Node name is wrong"
+    def test_ascii_character_error(self):
+        tree_str = "a\n|-- b\n|   |-- d\n|   +-- e\n|       |-- g\n|       +-- h\n+-- c\n    +-- f"
+        with pytest.raises(ValueError) as exc_info:
+            str_to_tree(tree_str)
+        assert str(exc_info.value).startswith(
+            "Invalid prefix, prefix should be unicode character or whitespace, otherwise specify one or more prefixes"
+        )
 
-    def test_list_to_tree_by_relation_empty(self):
-        with pytest.raises(ValueError):
-            list_to_tree_by_relation([])
+    def test_ascii_character_with_prefix(self):
+        tree_str = "a\n|-- b\n|   |-- d\n|   +-- e\n|       |-- g\n|       +-- h\n+-- c\n    +-- f"
+        root = str_to_tree(tree_str, tree_prefix_list=["-"])
+        assert_tree_structure_basenode_root_generic(root)
+        assert_tree_structure_node_root_generic(root)
 
-    def test_list_to_tree_by_relation_switch_order(self):
-        relations = [
-            ("h", "g"),
-            ("h", "f"),
-            ("g", "e"),
-            ("g", "d"),
-            ("g", "a"),
-            ("f", "a"),
-            ("d", "b"),
-            ("d", "a"),
-        ]
-        root = list_to_tree_by_relation(relations)
-        assert root.max_depth == 4
+    def test_empty_string(self):
+        with pytest.raises(ValueError) as exc_info:
+            str_to_tree("")
+        assert (
+            str(exc_info.value)
+            == "Tree string does not contain any data, check `tree_string`"
+        )
+
+    def test_empty_newline_string(self):
+        with pytest.raises(ValueError) as exc_info:
+            str_to_tree("\n\n")
+        assert (
+            str(exc_info.value)
+            == "Tree string does not contain any data, check `tree_string`"
+        )
+
+    def test_unequal_prefix_length(self):
+        tree_str = "a\n├── b\n│  ├── d\n│   └── e\n│       ├── g\n│       └── h\n└── c\n    └── f"
+        with pytest.raises(ValueError) as exc_info:
+            str_to_tree(tree_str)
+        assert str(exc_info.value).startswith(
+            "Tree string have different prefix length, check branch"
+        )
 
 
 class TestListToTree(unittest.TestCase):
@@ -1013,7 +996,7 @@ class TestListToTree(unittest.TestCase):
 
         root = list_to_tree(path_list)
         assert_tree_structure_basenode_root_generic(root)
-        assert_tree_structure_node_root_generic(root)
+        assert_tree_structure_node_root_generic(root, f="/a/c/d")
 
     def test_list_to_tree_node_type(self):
         root = list_to_tree(self.path_list, node_type=NodeA)
@@ -1036,6 +1019,104 @@ class TestListToTree(unittest.TestCase):
             list_to_tree(path_list)
 
 
+class TestListToTreeByRelation(unittest.TestCase):
+    def setUp(self):
+        """
+        Tree should have structure
+        a
+        |-- b
+        |   |-- d
+        |   +-- e
+        |       |-- g
+        |       +-- h
+        +-- c
+            +-- f
+        """
+        self.relations = [
+            ("a", "b"),
+            ("a", "c"),
+            ("b", "d"),
+            ("b", "e"),
+            ("c", "f"),
+            ("e", "g"),
+            ("e", "h"),
+        ]
+        self.relations_reverse = [
+            ("e", "g"),
+            ("e", "h"),
+            ("b", "d"),
+            ("b", "e"),
+            ("c", "f"),
+            ("a", "b"),
+            ("a", "c"),
+        ]
+        self.relations_switch = [
+            ("h", "g"),
+            ("h", "f"),
+            ("g", "e"),
+            ("g", "d"),
+            ("g", "a"),
+            ("f", "a"),
+            ("d", "b"),
+            ("d", "a"),
+        ]
+
+    def tearDown(self):
+        self.relations = None
+
+    def test_list_to_tree_by_relation(self):
+        root = list_to_tree_by_relation(self.relations)
+        assert_tree_structure_basenode_root_generic(root)
+        assert_tree_structure_node_root_generic(root)
+
+    def test_list_to_tree_by_relation_reverse(self):
+        root = list_to_tree_by_relation(self.relations_reverse)
+        assert_tree_structure_basenode_root_generic(root)
+        assert_tree_structure_node_root_generic(root)
+
+    @staticmethod
+    def test_list_to_tree_by_relation_duplicate_leaf_node():
+        relations = [
+            ("a", "b"),
+            ("a", "c"),
+            ("b", "d"),
+            ("b", "e"),
+            ("b", "h"),
+            ("c", "h"),
+            ("e", "g"),
+            ("e", "h"),
+        ]
+        root = list_to_tree_by_relation(relations)
+        expected = """a\n├── b\n│   ├── d\n│   ├── e\n│   │   ├── g\n│   │   └── h\n│   └── h\n└── c\n    └── h\n"""
+        assert_print_statement(print_tree, expected, tree=root, style="const")
+
+    def test_list_to_tree_by_relation_empty_parent(self):
+        self.relations.append((None, "a"))
+        root = list_to_tree_by_relation(self.relations)
+        assert_tree_structure_basenode_root_generic(root)
+        assert_tree_structure_node_root_generic(root)
+
+    @staticmethod
+    def test_list_to_tree_by_relation_one_tuple():
+        root = list_to_tree_by_relation([(None, "a")])
+        assert root.max_depth == 1, "Max depth is wrong"
+        assert root.node_name == "a", "Node name is wrong"
+
+    def test_list_to_tree_by_relation_empty(self):
+        with pytest.raises(ValueError):
+            list_to_tree_by_relation([])
+
+    def test_list_to_tree_by_relation_switch_order(self):
+        root = list_to_tree_by_relation(self.relations_switch)
+        expected = """h\n├── g\n│   ├── e\n│   ├── d\n│   │   ├── b\n│   │   └── a\n│   └── a\n└── f\n    └── a\n"""
+        assert_print_statement(print_tree, expected, root)
+
+    def test_list_to_tree_by_relation_switch_order_reverse(self):
+        root = list_to_tree_by_relation(self.relations_switch[::-1])
+        expected = """h\n├── f\n│   └── a\n└── g\n    ├── a\n    ├── d\n    │   ├── a\n    │   └── b\n    └── e\n"""
+        assert_print_statement(print_tree, expected, root)
+
+
 class TestDictToTree(unittest.TestCase):
     def setUp(self):
         """
@@ -1157,8 +1238,8 @@ class TestDictToTree(unittest.TestCase):
 
         root = dict_to_tree(path_dict)
         assert_tree_structure_basenode_root_generic(root)
-        assert_tree_structure_basenode_root_attr(root)
-        assert_tree_structure_node_root_generic(root)
+        assert_tree_structure_basenode_root_attr(root, f=("d", 38))
+        assert_tree_structure_node_root_generic(root, f="/a/c/d")
 
     def test_dict_to_tree_node_type(self):
         root = dict_to_tree(self.path_dict, node_type=NodeA)
@@ -1484,8 +1565,8 @@ class TestDataFrameToTree(unittest.TestCase):
 
         root = dataframe_to_tree(path_data)
         assert_tree_structure_basenode_root_generic(root)
-        assert_tree_structure_basenode_root_attr(root)
-        assert_tree_structure_node_root_generic(root)
+        assert_tree_structure_basenode_root_attr(root, f=("d", 38))
+        assert_tree_structure_node_root_generic(root, f="/a/c/d")
 
 
 class TestDataFrameToTreeByRelation(unittest.TestCase):
