@@ -8,6 +8,7 @@ from bigtree.tree.export import (
     tree_to_dict,
     tree_to_dot,
     tree_to_nested_dict,
+    tree_to_pillow,
 )
 from tests.conftest import assert_print_statement
 from tests.node.test_basenode import (
@@ -830,8 +831,48 @@ class TestTreeToDot:
         graph = tree_to_dot(tree_node_style, node_attr="node_style")
         expected = """strict digraph G {\nrankdir=TB;\na0 [fillcolor=gold, label=a, style=filled];\nb0 [fillcolor=blue, label=b, style=filled];\na0 -> b0;\nd0 [fillcolor=green, label=d, style=filled];\nb0 -> d0;\ng0 [fillcolor=red, label=g, style=filled];\nd0 -> g0;\ne0 [fillcolor=green, label=e, style=filled];\nb0 -> e0;\nh0 [fillcolor=red, label=h, style=filled];\ne0 -> h0;\nc0 [fillcolor=blue, label=c, style=filled];\na0 -> c0;\nf0 [fillcolor=green, label=f, style=filled];\nc0 -> f0;\n}\n"""
         actual = graph.to_string()
-        graph.write_png("tests/tree_style.png")
+        graph.write_png("tests/tree_node_style.png")
         for expected_str in expected.split():
             assert (
                 expected_str in actual
             ), f"Expected {expected_str} not in actual string"
+
+    @staticmethod
+    def test_tree_to_dot_edge_attr(tree_node_style):
+        graph = tree_to_dot(tree_node_style, edge_attr="edge_style")
+        expected = """strict digraph G {\nrankdir=TB;\na0 [label=a];\nb0 [label=b];\na0 -> b0  [label=b, style=bold];\nd0 [label=d];\nb0 -> d0  [label=1, style=bold];\ng0 [label=g];\nd0 -> g0  [label=4, style=bold];\ne0 [label=e];\nb0 -> e0  [label=2, style=bold];\nh0 [label=h];\ne0 -> h0  [label=5, style=bold];\nc0 [label=c];\na0 -> c0  [label=c, style=bold];\nf0 [label=f];\nc0 -> f0  [label=3, style=bold];\n}\n"""
+        actual = graph.to_string()
+        graph.write_png("tests/tree_edge_style.png")
+        for expected_str in expected.split():
+            assert (
+                expected_str in actual
+            ), f"Expected {expected_str} not in actual string"
+
+
+class TestTreeToPillow:
+    @staticmethod
+    def test_tree_to_pillow(tree_node):
+        pillow_image = tree_to_pillow(tree_node)
+        pillow_image.save("tests/tree_pillow.png")
+
+    @staticmethod
+    def test_tree_to_pillow_start_pos(tree_node):
+        pillow_image = tree_to_pillow(tree_node, start_pos=(100, 50))
+        pillow_image.save("tests/tree_pillow_start_pos.png")
+
+    @staticmethod
+    def test_tree_to_pillow_start_pos_small(tree_node):
+        pillow_image = tree_to_pillow(tree_node, start_pos=(0, 0))
+        pillow_image.save("tests/tree_pillow_start_pos_small.png")
+
+    @staticmethod
+    def test_tree_to_pillow_font(tree_node):
+        pillow_image = tree_to_pillow(
+            tree_node, font_size=20, font_colour="red", bg_colour="lightblue"
+        )
+        pillow_image.save("tests/tree_pillow_font.png")
+
+    @staticmethod
+    def test_tree_to_pillow_kwargs(tree_node):
+        pillow_image = tree_to_pillow(tree_node, max_depth=2, style="const_bold")
+        pillow_image.save("tests/tree_pillow_style.png")
